@@ -1,3 +1,5 @@
+from __future__ import unicode_literals
+
 from ..forms import CreditCardPaymentForm
 
 RESPONSE_STATUS = {
@@ -16,12 +18,12 @@ class PaymentForm(CreditCardPaymentForm):
                     'x_card_num': cleaned_data.get('number'),
                     'x_exp_date': cleaned_data.get('expiration'),
                     'x_card_code': cleaned_data.get('cvv2')}
-
                 response = self.provider.get_payment_response(data)
                 data = response.text.split('|')
                 if response.ok and RESPONSE_STATUS.get(data[0], False):
                     self.payment.transaction_id = data[6]
-                    self.payment.change_status(RESPONSE_STATUS.get(data[0], 'error'))
+                    self.payment.change_status(
+                        RESPONSE_STATUS.get(data[0], 'error'))
                 else:
                     errors = [data[3]]
                     self._errors['__all__'] = self.error_class(errors)
